# DockerImage

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**created_at** | **str** |  | [optional] 
**created_since** | **str** |  | [optional] 
**id** | **str** |  | [optional] 
**repository** | **str** |  | [optional] 
**size** | **str** |  | [optional] 
**tag** | **str** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


